# ml_ms4alg

Electrophysiology tools
MountainLab processor library

Installation from PyPI:

```
pip3 install --upgrade ml_ms4alg
```

Then add it as a plugin to mountainlab:

```
cd ~/.mountainlab/packages
ml-link-python-module ml_ms4alg ml_ms4alg
```

Or installation from source:

* clone this repository into .mountainlab/packages/

```
cd ml_ms4alg
pip3 install --upgrade .
```
